@@ -20,7 +20,7 @@ class BaseClient(abc.ABC):
     @abc.abstractmethod
     async def insert(
         self, model: DocumentDBModel, include=None, exclude=None, session: Any = None,
-    ):
+    ) -> WriteResult:
         pass
 
     @abc.abstractmethod
@@ -29,7 +29,7 @@ class BaseClient(abc.ABC):
 
     @abc.abstractmethod
     async def get(
-        self, model: Type[DocumentDBModel], id: str, session: Any = None
+        self, model: Type[DocumentDBModel], _id: str, session: Any = None
     ) -> Optional[DocumentDBModel]:
         pass
 
@@ -74,12 +74,13 @@ class BaseClient(abc.ABC):
     ) -> WriteResult:
         pass
 
-    @abc.abstractmethod
-    async def update_many(
-        self, model: Type[DocumentDBModel], data: List[Tuple[str, dict]]
-    ) -> WriteResult:
-        pass
-
     @abc.abstractmethod
     async def create_indexes(self, index=List[DBIndex]) -> Optional[List[str]]:
         pass
+
+    # FIXME: Need to add this back once it has been fixed
+    # @abc.abstractmethod
+    # async def update_many(
+    #     self, model: Type[DocumentDBModel], data: List[Tuple[str, dict]]
+    # ) -> WriteResult:
+    #     pass
