@@ -2,6 +2,7 @@ from fastapi import FastAPI
 from fastapi.exceptions import RequestValidationError
 from starlette.exceptions import HTTPException as StarletteHTTPException
 from starlette.requests import Request
+from pydantic import ValidationError
 
 from .responses import UJSONResponse
 from .utils import logger as LOG
@@ -51,6 +52,29 @@ async def validation_exception_handler(
     return UJSONResponse(data, status_code=status_code)
 
 
+async def pydantic_validation_exception_handler(
+    request: Request, exc: ValidationError
+) -> UJSONResponse:
+    """
+    Handles ValidationError, translating it into flat dict error data:
+        * code - unique code of the error in the system
+        * detail - general description of the error
+        * fields - list of dicts with description of the error in each field
+
+    :param request: Starlette Request instance
+    :param exc: StarletteHTTPException instance
+    :return: UJSONResponse with newly formatted error data
+    """
+    LOG.error(f"Unhandled Pydantic ValidationError Caught: {str(exc)}")
+    status_code = getattr(exc, "status_code", 500)
+    data = {
+        "code": getattr(exc, "error_code", status_code),
+        "detail": f"A domain object has failed validation this is likely due to changes in the database "
+        + f"structure. Error: {exc}",
+    }
+    return UJSONResponse(data, status_code=status_code)
+
+
 async def assert_exception(request: Request, exc: AssertionError) -> UJSONResponse:
     LOG.warning(f"Assert exception caught: {str(exc)}")
     status_code = getattr(exc, "status_code", 400)
@@ -89,5 +113,6 @@ def setup_exception_handlers(app: FastAPI) -> None:
     """
     app.add_exception_handler(StarletteHTTPException, http_exception_handler)
     app.add_exception_handler(RequestValidationError, validation_exception_handler)
+    app.add_exception_handler(ValidationError, pydantic_validation_exception_handler)
     app.add_exception_handler(AssertionError, assert_exception)
     app.add_exception_handler(Exception, default_exception)
