@@ -254,7 +254,9 @@ class MinioClient(BaseClient):
             )
             raise StorageError(f"Somthing went wrong copying {from_path} to {to_path}")
 
-    async def create_temp_file_ref(self, bucket: str, path: str) -> File:
+    async def create_temp_file_url(
+        self, bucket: str, path: str, expire_time_hours: int = 3
+    ) -> File:
         # FIXME make this work
         raise NotImplementedError(
             "Minio support for temp downloads currently not working."
