@@ -1,6 +1,7 @@
 import functools
 import importlib
 import logging
+import asyncio
 import os
 import sys
 from datetime import datetime
@@ -18,72 +19,6 @@ from .config import get_settings
 current_app: Optional[FastAPI] = None
 
 
-def force_async(fn):
-    """
-    turns a sync function to async function using threads
-    """
-    from concurrent.futures import ThreadPoolExecutor
-    import asyncio
-
-    pool = ThreadPoolExecutor()
-
-    @functools.wraps(fn)
-    def wrapper(*args, **kwargs):
-        future = pool.submit(fn, *args, **kwargs)
-        return asyncio.wrap_future(future)  # make it awaitable
-
-    return wrapper
-
-
-def force_sync(fn):
-    """
-    turn an async function to sync function
-    """
-    import asyncio
-
-    @functools.wraps(fn)
-    def wrapper(*args, **kwargs):
-        res = fn(*args, **kwargs)
-        if asyncio.iscoroutine(res):
-            return asyncio.get_event_loop().run_until_complete(res)
-        return res
-
-    return wrapper
-
-
-def sizeof_fmt(num: Optional[Any], suffix="B") -> str:
-    if num is None:
-        return ""
-    for unit in ["", "K", "M", "G", "T", "P", "E", "Z"]:
-        if abs(num) < 1024.0:
-            return "%3.1f%s%s" % (num, unit, suffix)
-        num /= 1024.0
-    return "%.1f%s%s" % (num, "Y", suffix)
-
-
-def resolve_dotted_path(path: str) -> Any:
-    """
-    Retrieves attribute (var, function, class, etc.) from module by dotted path.
-    .. code-block:: python
-        from datetime.datetime import utcnow as default_utcnow
-        utcnow = resolve_dotted_path('datetime.datetime.utcnow')
-        assert utcnow == default_utcnow
-    :param path: dotted path to the attribute in module
-    :return: desired attribute or None
-    """
-    splitted = path.split(".")
-    if len(splitted) <= 1:
-        return importlib.import_module(path)
-    module, attr = ".".join(splitted[:-1]), splitted[-1]
-    module = importlib.import_module(module)  # type: ignore
-    return getattr(module, attr)
-
-
-class PropagateHandler(logging.Handler):
-    def emit(self, record):
-        logging.getLogger("gunicorn.error").handle(record)
-
-
 def get_logger() -> Any:
     """
     Gets logger that will be used throughout this whole library.
@@ -131,13 +66,93 @@ def get_logger() -> Any:
 logger = get_logger()
 
 
-async def async_get(url, auth: str = None):
+def force_async(fn):
+    """
+    turns a sync function to async function using threads
+    """
+    from concurrent.futures import ThreadPoolExecutor
+
+    pool = ThreadPoolExecutor()
+
+    @functools.wraps(fn)
+    def wrapper(*args, **kwargs):
+        future = pool.submit(fn, *args, **kwargs)
+        return asyncio.wrap_future(future)  # make it awaitable
+
+    return wrapper
+
+
+def force_sync(fn):
+    """
+    turn an async function to sync function
+    """
+
+    @functools.wraps(fn)
+    def wrapper(*args, **kwargs):
+        res = fn(*args, **kwargs)
+        if asyncio.iscoroutine(res):
+            return asyncio.get_event_loop().run_until_complete(res)
+        return res
+
+    return wrapper
+
+
+def sizeof_fmt(num: Optional[Any], suffix="B") -> str:
+    if num is None:
+        return ""
+    for unit in ["", "K", "M", "G", "T", "P", "E", "Z"]:
+        if abs(num) < 1024.0:
+            return "%3.1f%s%s" % (num, unit, suffix)
+        num /= 1024.0
+    return "%.1f%s%s" % (num, "Y", suffix)
+
+
+def resolve_dotted_path(path: str) -> Any:
+    """
+    Retrieves attribute (var, function, class, etc.) from module by dotted path.
+    .. code-block:: python
+        from datetime.datetime import utcnow as default_utcnow
+        utcnow = resolve_dotted_path('datetime.datetime.utcnow')
+        assert utcnow == default_utcnow
+    :param path: dotted path to the attribute in module
+    :return: desired attribute or None
+    """
+    splitted = path.split(".")
+    if len(splitted) <= 1:
+        return importlib.import_module(path)
+    module, attr = ".".join(splitted[:-1]), splitted[-1]
+    module = importlib.import_module(module)  # type: ignore
+    return getattr(module, attr)
+
+
+class PropagateHandler(logging.Handler):
+    def emit(self, record):
+        logging.getLogger("gunicorn.error").handle(record)
+
+
+async def async_get(url, auth: str = None, json_only=True, retry: bool = True):
     async with aiohttp.ClientSession() as session:
         headers = {}
         if auth is not None:
             headers = {"Authorization": auth}
-        async with session.get(url, headers=headers) as response:
+        response = await session.get(url, headers=headers)
+        response.raise_for_status()
+        if response.content_type == "application/json":
             return await response.json()
+        elif json_only:
+            logger.warning(
+                f"Async call {url} was expecting JSON but got: {await response.text()}"
+            )
+            if retry:
+                logger.warning(f"Retrying get {url} in 2 seconds")
+                await asyncio.sleep(2)
+                return await async_get(url, auth, json_only, retry=False)
+            else:
+                raise ValueError(
+                    f"get {url} is returning a non json response: {await response.text()}"
+                )
+        else:
+            return await response.text()
 
 
 def get_current_app() -> FastAPI:
