@@ -9,6 +9,7 @@ from fa_common.workflow import (
     get_job_log,
     create_workflow_project,
     WorkflowProject,
+    get_workflow_client,
 )
 from fa_common.storage import File
 from .conftest import get_env_file, TEST_GITLAB_PROJECT, TEST_GITLAB_BRANCH
@@ -64,16 +65,25 @@ async def test_job_create(ensure_test_gitlab):
     ]
 
     job_run = await run_job(
-        project, "Sync Unit Test", module, job_data, files, sync=True
+        project,
+        "Sync Unit Test",
+        module,
+        job_data,
+        runner="csiro-swarm",
+        files=files,
+        sync=True,
     )
 
     assert job_run.status == "success"
     assert job_run.output is not None
 
-    job_run2 = await get_job_run(project_id, job_run.id, True)
+    job_run2 = await get_job_run(project_id, job_run.id, False)
 
     assert job_run2.id == job_run.id
 
+    job_logs = await get_job_log(project_id, job_run.id)
+    assert job_logs is not None
+
 
 @pytest.mark.asyncio
 async def test_job_create_async(ensure_test_gitlab):
@@ -107,9 +117,50 @@ async def test_job_create_async(ensure_test_gitlab):
         )
     ]
 
-    job_run = await run_job(project, "Async Unit Test", module, job_data, files)
+    job_run = await run_job(
+        project, "Async Unit Test", module, job_data, runner="csiro-swarm", files=files
+    )
 
     job_run2 = await get_job_run(project_id, job_run.id)
 
     assert job_run2.id == job_run.id
-    job_logs = await get_job_log(project_id, job_run.id)
+
+
+# @pytest.mark.asyncio
+# async def test_large_job_create_async(ensure_test_gitlab):
+#     project_id = ensure_test_gitlab
+#     assert project_id > 0
+
+#     project = WorkflowProject(
+#         name=TEST_GITLAB_BRANCH,
+#         user_id=TEST_GITLAB_PROJECT,
+#         gitlab_project_id=project_id,
+#         timezone="Australia/Perth",
+#     )
+
+#     module = ScidraModule(
+#         name="galei-inversion",
+#         docker_image="registry.gitlab.com/csiro-geoanalytics/gpt/modules/galei-inversion-module:latest",
+#         cpu_limit=4,
+#         cpu_request=2,
+#         memory_limit_gb=16,
+#         memory_request_gb=4,
+#     )
+#     job_data = {"test": "subset"}
+
+#     job_run = await run_job(
+#         project, "Inversion Test", module, job_data, runner="csiro-easi-hub"
+#     )
+
+#     assert job_run.id is not None
+
+
+@pytest.mark.asyncio
+async def test_delete_workflow_project():
+    client = get_workflow_client()
+    try:
+        project = await client._get_project_by_name(TEST_GITLAB_PROJECT)
+    except ValueError:
+        return
+
+    await client.delete_project(project.id, False)
